# coding: utf-8

"""
    Data Repository API

    <details><summary>This document defines the REST API for the Terra Data Repository.</summary> <p> **Status: design in progress** There are a few top-level endpoints (besides some used by swagger):  * / - generated by swagger: swagger API page that provides this documentation and a live UI for submitting REST requests  * /status - provides the operational status of the service  * /configuration - provides the basic configuration and information about the service  * /api - is the authenticated and authorized Data Repository API  * /ga4gh/drs/v1 - is a transcription of the Data Repository Service API  The API endpoints are organized by interface. Each interface is separately versioned. <p> **Notes on Naming** <p> All of the reference items are suffixed with \\\"Model\\\". Those names are used as the class names in the generated Java code. It is helpful to distinguish these model classes from other related classes, like the DAO classes and the operation classes. </details>   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from data_repo_client.configuration import Configuration


class FileLoadModel(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'source_path': 'str',
        'target_path': 'str',
        'mime_type': 'str',
        'profile_id': 'str',
        'load_tag': 'str',
        'description': 'str'
    }

    attribute_map = {
        'source_path': 'source_path',
        'target_path': 'target_path',
        'mime_type': 'mime_type',
        'profile_id': 'profileId',
        'load_tag': 'loadTag',
        'description': 'description'
    }

    def __init__(self, source_path=None, target_path=None, mime_type=None, profile_id=None, load_tag=None, description=None, local_vars_configuration=None):  # noqa: E501
        """FileLoadModel - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._source_path = None
        self._target_path = None
        self._mime_type = None
        self._profile_id = None
        self._load_tag = None
        self._description = None
        self.discriminator = None

        self.source_path = source_path
        self.target_path = target_path
        if mime_type is not None:
            self.mime_type = mime_type
        if profile_id is not None:
            self.profile_id = profile_id
        if load_tag is not None:
            self.load_tag = load_tag
        if description is not None:
            self.description = description

    @property
    def source_path(self):
        """Gets the source_path of this FileLoadModel.  # noqa: E501

        gs URL of the source file to load  # noqa: E501

        :return: The source_path of this FileLoadModel.  # noqa: E501
        :rtype: str
        """
        return self._source_path

    @source_path.setter
    def source_path(self, source_path):
        """Sets the source_path of this FileLoadModel.

        gs URL of the source file to load  # noqa: E501

        :param source_path: The source_path of this FileLoadModel.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and source_path is None:  # noqa: E501
            raise ValueError("Invalid value for `source_path`, must not be `None`")  # noqa: E501

        self._source_path = source_path

    @property
    def target_path(self):
        """Gets the target_path of this FileLoadModel.  # noqa: E501

        Full path within the dataset where the file should be placed. The path must start with /.   # noqa: E501

        :return: The target_path of this FileLoadModel.  # noqa: E501
        :rtype: str
        """
        return self._target_path

    @target_path.setter
    def target_path(self, target_path):
        """Sets the target_path of this FileLoadModel.

        Full path within the dataset where the file should be placed. The path must start with /.   # noqa: E501

        :param target_path: The target_path of this FileLoadModel.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and target_path is None:  # noqa: E501
            raise ValueError("Invalid value for `target_path`, must not be `None`")  # noqa: E501

        self._target_path = target_path

    @property
    def mime_type(self):
        """Gets the mime_type of this FileLoadModel.  # noqa: E501

        A string providing the mime-type of the Data Object. For example, \"application/json\".  # noqa: E501

        :return: The mime_type of this FileLoadModel.  # noqa: E501
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """Sets the mime_type of this FileLoadModel.

        A string providing the mime-type of the Data Object. For example, \"application/json\".  # noqa: E501

        :param mime_type: The mime_type of this FileLoadModel.  # noqa: E501
        :type: str
        """

        self._mime_type = mime_type

    @property
    def profile_id(self):
        """Gets the profile_id of this FileLoadModel.  # noqa: E501

        Unique identifier for a dataset, snapshot, etc.   # noqa: E501

        :return: The profile_id of this FileLoadModel.  # noqa: E501
        :rtype: str
        """
        return self._profile_id

    @profile_id.setter
    def profile_id(self, profile_id):
        """Sets the profile_id of this FileLoadModel.

        Unique identifier for a dataset, snapshot, etc.   # noqa: E501

        :param profile_id: The profile_id of this FileLoadModel.  # noqa: E501
        :type: str
        """

        self._profile_id = profile_id

    @property
    def load_tag(self):
        """Gets the load_tag of this FileLoadModel.  # noqa: E501

        client-specified tag for a data or file load. If no id is specified, we use the string form of the job create time as the tag.   # noqa: E501

        :return: The load_tag of this FileLoadModel.  # noqa: E501
        :rtype: str
        """
        return self._load_tag

    @load_tag.setter
    def load_tag(self, load_tag):
        """Sets the load_tag of this FileLoadModel.

        client-specified tag for a data or file load. If no id is specified, we use the string form of the job create time as the tag.   # noqa: E501

        :param load_tag: The load_tag of this FileLoadModel.  # noqa: E501
        :type: str
        """

        self._load_tag = load_tag

    @property
    def description(self):
        """Gets the description of this FileLoadModel.  # noqa: E501

        A human readable description of the contents of the Data Object.  # noqa: E501

        :return: The description of this FileLoadModel.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this FileLoadModel.

        A human readable description of the contents of the Data Object.  # noqa: E501

        :param description: The description of this FileLoadModel.  # noqa: E501
        :type: str
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileLoadModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FileLoadModel):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Data Repository API

    <details><summary>This document defines the REST API for the Terra Data Repository.</summary> <p> **Status: design in progress** There are a few top-level endpoints (besides some used by swagger):  * / - generated by swagger: swagger API page that provides this documentation and a live UI for submitting REST requests  * /status - provides the operational status of the service  * /configuration - provides the basic configuration and information about the service  * /api - is the authenticated and authorized Data Repository API  * /ga4gh/drs/v1 - is a transcription of the Data Repository Service API  The API endpoints are organized by interface. Each interface is separately versioned. <p> **Notes on Naming** <p> All of the reference items are suffixed with \\\"Model\\\". Those names are used as the class names in the generated Java code. It is helpful to distinguish these model classes from other related classes, like the DAO classes and the operation classes. </details>   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from data_repo_client.configuration import Configuration


class SnapshotRequestModel(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'description': 'str',
        'consent_code': 'str',
        'contents': 'list[SnapshotRequestContentsModel]',
        'readers': 'list[str]',
        'profile_id': 'str',
        'properties': 'object',
        'policies': 'SnapshotRequestModelPolicies'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'consent_code': 'consentCode',
        'contents': 'contents',
        'readers': 'readers',
        'profile_id': 'profileId',
        'properties': 'properties',
        'policies': 'policies'
    }

    def __init__(self, name=None, description=None, consent_code=None, contents=None, readers=None, profile_id=None, properties=None, policies=None, local_vars_configuration=None):  # noqa: E501
        """SnapshotRequestModel - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._description = None
        self._consent_code = None
        self._contents = None
        self._readers = None
        self._profile_id = None
        self._properties = None
        self._policies = None
        self.discriminator = None

        self.name = name
        if description is not None:
            self.description = description
        if consent_code is not None:
            self.consent_code = consent_code
        self.contents = contents
        if readers is not None:
            self.readers = readers
        if profile_id is not None:
            self.profile_id = profile_id
        if properties is not None:
            self.properties = properties
        if policies is not None:
            self.policies = policies

    @property
    def name(self):
        """Gets the name of this SnapshotRequestModel.  # noqa: E501

        Dataset and snapshot names follow this pattern. It is the same as ObjectNameProperty, but has a greater maxLength.   # noqa: E501

        :return: The name of this SnapshotRequestModel.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SnapshotRequestModel.

        Dataset and snapshot names follow this pattern. It is the same as ObjectNameProperty, but has a greater maxLength.   # noqa: E501

        :param name: The name of this SnapshotRequestModel.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 511):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `511`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and not re.search(r'^[a-zA-Z0-9][_a-zA-Z0-9]*$', name)):  # noqa: E501
            raise ValueError(r"Invalid value for `name`, must be a follow pattern or equal to `/^[a-zA-Z0-9][_a-zA-Z0-9]*$/`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this SnapshotRequestModel.  # noqa: E501

        Description of the snapshot  # noqa: E501

        :return: The description of this SnapshotRequestModel.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SnapshotRequestModel.

        Description of the snapshot  # noqa: E501

        :param description: The description of this SnapshotRequestModel.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def consent_code(self):
        """Gets the consent_code of this SnapshotRequestModel.  # noqa: E501

        Consent code together with PHS ID that will determine user access  # noqa: E501

        :return: The consent_code of this SnapshotRequestModel.  # noqa: E501
        :rtype: str
        """
        return self._consent_code

    @consent_code.setter
    def consent_code(self, consent_code):
        """Sets the consent_code of this SnapshotRequestModel.

        Consent code together with PHS ID that will determine user access  # noqa: E501

        :param consent_code: The consent_code of this SnapshotRequestModel.  # noqa: E501
        :type: str
        """

        self._consent_code = consent_code

    @property
    def contents(self):
        """Gets the contents of this SnapshotRequestModel.  # noqa: E501


        :return: The contents of this SnapshotRequestModel.  # noqa: E501
        :rtype: list[SnapshotRequestContentsModel]
        """
        return self._contents

    @contents.setter
    def contents(self, contents):
        """Sets the contents of this SnapshotRequestModel.


        :param contents: The contents of this SnapshotRequestModel.  # noqa: E501
        :type: list[SnapshotRequestContentsModel]
        """
        if self.local_vars_configuration.client_side_validation and contents is None:  # noqa: E501
            raise ValueError("Invalid value for `contents`, must not be `None`")  # noqa: E501

        self._contents = contents

    @property
    def readers(self):
        """Gets the readers of this SnapshotRequestModel.  # noqa: E501

        Deprecated -- use `policies.readers` instead. Any readers specified here will supplement those set in `policies.readers`.   # noqa: E501

        :return: The readers of this SnapshotRequestModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._readers

    @readers.setter
    def readers(self, readers):
        """Sets the readers of this SnapshotRequestModel.

        Deprecated -- use `policies.readers` instead. Any readers specified here will supplement those set in `policies.readers`.   # noqa: E501

        :param readers: The readers of this SnapshotRequestModel.  # noqa: E501
        :type: list[str]
        """

        self._readers = readers

    @property
    def profile_id(self):
        """Gets the profile_id of this SnapshotRequestModel.  # noqa: E501

        Unique identifier for a dataset, snapshot, etc.   # noqa: E501

        :return: The profile_id of this SnapshotRequestModel.  # noqa: E501
        :rtype: str
        """
        return self._profile_id

    @profile_id.setter
    def profile_id(self, profile_id):
        """Sets the profile_id of this SnapshotRequestModel.

        Unique identifier for a dataset, snapshot, etc.   # noqa: E501

        :param profile_id: The profile_id of this SnapshotRequestModel.  # noqa: E501
        :type: str
        """

        self._profile_id = profile_id

    @property
    def properties(self):
        """Gets the properties of this SnapshotRequestModel.  # noqa: E501

        Additional JSON metadata about the snapshot (this does not need to adhere to a particular schema)  # noqa: E501

        :return: The properties of this SnapshotRequestModel.  # noqa: E501
        :rtype: object
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this SnapshotRequestModel.

        Additional JSON metadata about the snapshot (this does not need to adhere to a particular schema)  # noqa: E501

        :param properties: The properties of this SnapshotRequestModel.  # noqa: E501
        :type: object
        """

        self._properties = properties

    @property
    def policies(self):
        """Gets the policies of this SnapshotRequestModel.  # noqa: E501


        :return: The policies of this SnapshotRequestModel.  # noqa: E501
        :rtype: SnapshotRequestModelPolicies
        """
        return self._policies

    @policies.setter
    def policies(self, policies):
        """Sets the policies of this SnapshotRequestModel.


        :param policies: The policies of this SnapshotRequestModel.  # noqa: E501
        :type: SnapshotRequestModelPolicies
        """

        self._policies = policies

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SnapshotRequestModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SnapshotRequestModel):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Data Repository API

    <details><summary>This document defines the REST API for the Terra Data Repository.</summary> <p> **Status: design in progress** There are a few top-level endpoints (besides some used by swagger):  * / - generated by swagger: swagger API page that provides this documentation and a live UI for submitting REST requests  * /status - provides the operational status of the service  * /configuration - provides the basic configuration and information about the service  * /api - is the authenticated and authorized Data Repository API  * /ga4gh/drs/v1 - is a transcription of the Data Repository Service API  The API endpoints are organized by interface. Each interface is separately versioned. <p> **Notes on Naming** <p> All of the reference items are suffixed with \\\"Model\\\". Those names are used as the class names in the generated Java code. It is helpful to distinguish these model classes from other related classes, like the DAO classes and the operation classes. </details>   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import data_repo_client
from data_repo_client.api.repository_api import RepositoryApi  # noqa: E501
from data_repo_client.rest import ApiException


class TestRepositoryApi(unittest.TestCase):
    """RepositoryApi unit test stubs"""

    def setUp(self):
        self.api = data_repo_client.api.repository_api.RepositoryApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_dataset_asset_specifications(self):
        """Test case for add_dataset_asset_specifications

        """
        pass

    def test_add_dataset_policy_member(self):
        """Test case for add_dataset_policy_member

        """
        pass

    def test_add_snapshot_policy_member(self):
        """Test case for add_snapshot_policy_member

        """
        pass

    def test_apply_dataset_data_deletion(self):
        """Test case for apply_dataset_data_deletion

        """
        pass

    def test_bulk_file_load(self):
        """Test case for bulk_file_load

        """
        pass

    def test_bulk_file_load_array(self):
        """Test case for bulk_file_load_array

        """
        pass

    def test_bulk_file_results_delete(self):
        """Test case for bulk_file_results_delete

        """
        pass

    def test_close_transaction(self):
        """Test case for close_transaction

        """
        pass

    def test_create_dataset(self):
        """Test case for create_dataset

        """
        pass

    def test_create_search_index(self):
        """Test case for create_search_index

        """
        pass

    def test_create_snapshot(self):
        """Test case for create_snapshot

        """
        pass

    def test_delete_dataset(self):
        """Test case for delete_dataset

        """
        pass

    def test_delete_dataset_policy_member(self):
        """Test case for delete_dataset_policy_member

        """
        pass

    def test_delete_file(self):
        """Test case for delete_file

        """
        pass

    def test_delete_snapshot(self):
        """Test case for delete_snapshot

        """
        pass

    def test_delete_snapshot_policy_member(self):
        """Test case for delete_snapshot_policy_member

        """
        pass

    def test_enumerate_datasets(self):
        """Test case for enumerate_datasets

        """
        pass

    def test_enumerate_jobs(self):
        """Test case for enumerate_jobs

        """
        pass

    def test_enumerate_snapshots(self):
        """Test case for enumerate_snapshots

        """
        pass

    def test_enumerate_transactions(self):
        """Test case for enumerate_transactions

        """
        pass

    def test_export_snapshot(self):
        """Test case for export_snapshot

        """
        pass

    def test_get_config(self):
        """Test case for get_config

        """
        pass

    def test_get_config_list(self):
        """Test case for get_config_list

        """
        pass

    def test_get_load_history_for_load_tag(self):
        """Test case for get_load_history_for_load_tag

        """
        pass

    def test_ingest_dataset(self):
        """Test case for ingest_dataset

        """
        pass

    def test_ingest_file(self):
        """Test case for ingest_file

        """
        pass

    def test_link_duos_dataset_to_snapshot(self):
        """Test case for link_duos_dataset_to_snapshot

        """
        pass

    def test_lookup_file_by_id(self):
        """Test case for lookup_file_by_id

        """
        pass

    def test_lookup_file_by_path(self):
        """Test case for lookup_file_by_path

        """
        pass

    def test_lookup_snapshot_file_by_id(self):
        """Test case for lookup_snapshot_file_by_id

        """
        pass

    def test_lookup_snapshot_file_by_path(self):
        """Test case for lookup_snapshot_file_by_path

        """
        pass

    def test_lookup_snapshot_preview_by_id(self):
        """Test case for lookup_snapshot_preview_by_id

        """
        pass

    def test_open_transaction(self):
        """Test case for open_transaction

        """
        pass

    def test_patch_dataset(self):
        """Test case for patch_dataset

        """
        pass

    def test_patch_snapshot(self):
        """Test case for patch_snapshot

        """
        pass

    def test_query_search_indices(self):
        """Test case for query_search_indices

        """
        pass

    def test_remove_dataset_asset_specifications(self):
        """Test case for remove_dataset_asset_specifications

        """
        pass

    def test_reset_config(self):
        """Test case for reset_config

        """
        pass

    def test_retrieve_dataset(self):
        """Test case for retrieve_dataset

        """
        pass

    def test_retrieve_dataset_policies(self):
        """Test case for retrieve_dataset_policies

        """
        pass

    def test_retrieve_duos_firecloud_group(self):
        """Test case for retrieve_duos_firecloud_group

        """
        pass

    def test_retrieve_duos_firecloud_groups(self):
        """Test case for retrieve_duos_firecloud_groups

        """
        pass

    def test_retrieve_job(self):
        """Test case for retrieve_job

        """
        pass

    def test_retrieve_job_result(self):
        """Test case for retrieve_job_result

        """
        pass

    def test_retrieve_snapshot(self):
        """Test case for retrieve_snapshot

        """
        pass

    def test_retrieve_snapshot_policies(self):
        """Test case for retrieve_snapshot_policies

        """
        pass

    def test_retrieve_transaction(self):
        """Test case for retrieve_transaction

        """
        pass

    def test_retrieve_user_dataset_roles(self):
        """Test case for retrieve_user_dataset_roles

        """
        pass

    def test_retrieve_user_snapshot_roles(self):
        """Test case for retrieve_user_snapshot_roles

        """
        pass

    def test_set_config_list(self):
        """Test case for set_config_list

        """
        pass

    def test_set_fault(self):
        """Test case for set_fault

        """
        pass

    def test_sync_duos_dataset_authorized_users(self):
        """Test case for sync_duos_dataset_authorized_users

        """
        pass

    def test_unlink_duos_dataset_from_snapshot(self):
        """Test case for unlink_duos_dataset_from_snapshot

        """
        pass

    def test_update_schema(self):
        """Test case for update_schema

        """
        pass

    def test_upgrade(self):
        """Test case for upgrade

        """
        pass

    def test_user(self):
        """Test case for user

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Data Repository API

    <details><summary>This document defines the REST API for the Terra Data Repository.</summary> <p> **Status: design in progress** There are a few top-level endpoints (besides some used by swagger):  * / - generated by swagger: swagger API page that provides this documentation and a live UI for submitting REST requests  * /status - provides the operational status of the service  * /configuration - provides the basic configuration and information about the service  * /api - is the authenticated and authorized Data Repository API  * /ga4gh/drs/v1 - is a transcription of the Data Repository Service API  The API endpoints are organized by interface. Each interface is separately versioned. <p> **Notes on Naming** <p> All of the reference items are suffixed with \\\"Model\\\". Those names are used as the class names in the generated Java code. It is helpful to distinguish these model classes from other related classes, like the DAO classes and the operation classes. </details>   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from data_repo_client.api_client import ApiClient
from data_repo_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class DuosApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def retrieve_duos_firecloud_group(self, duos_id, **kwargs):  # noqa: E501
        """retrieve_duos_firecloud_group  # noqa: E501

        Returns a DUOS Firecloud group managed by TDR. NOTE: This is an experimental feature and its response body may change.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_duos_firecloud_group(duos_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str duos_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DuosFirecloudGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.retrieve_duos_firecloud_group_with_http_info(duos_id, **kwargs)  # noqa: E501

    def retrieve_duos_firecloud_group_with_http_info(self, duos_id, **kwargs):  # noqa: E501
        """retrieve_duos_firecloud_group  # noqa: E501

        Returns a DUOS Firecloud group managed by TDR. NOTE: This is an experimental feature and its response body may change.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_duos_firecloud_group_with_http_info(duos_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str duos_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DuosFirecloudGroupModel, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'duos_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_duos_firecloud_group" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'duos_id' is set
        if self.api_client.client_side_validation and ('duos_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['duos_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `duos_id` when calling `retrieve_duos_firecloud_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'duos_id' in local_var_params:
            path_params['duosId'] = local_var_params['duos_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['googleoauth', 'oidc']  # noqa: E501

        return self.api_client.call_api(
            '/api/repository/v1/duos/{duosId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DuosFirecloudGroupModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_duos_firecloud_groups(self, **kwargs):  # noqa: E501
        """retrieve_duos_firecloud_groups  # noqa: E501

        Returns a list of all DUOS Firecloud groups managed by TDR. NOTE: This is an experimental feature and its response body may change.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_duos_firecloud_groups(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[DuosFirecloudGroupModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.retrieve_duos_firecloud_groups_with_http_info(**kwargs)  # noqa: E501

    def retrieve_duos_firecloud_groups_with_http_info(self, **kwargs):  # noqa: E501
        """retrieve_duos_firecloud_groups  # noqa: E501

        Returns a list of all DUOS Firecloud groups managed by TDR. NOTE: This is an experimental feature and its response body may change.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_duos_firecloud_groups_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[DuosFirecloudGroupModel], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_duos_firecloud_groups" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['googleoauth', 'oidc']  # noqa: E501

        return self.api_client.call_api(
            '/api/repository/v1/duos', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DuosFirecloudGroupModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def sync_duos_dataset_authorized_users(self, duos_id, **kwargs):  # noqa: E501
        """sync_duos_dataset_authorized_users  # noqa: E501

        Sync the DUOS dataset's authorized users as members of their corresponding TDR-managed Firecloud group.  Any snapshots linked to the DUOS dataset have this Firecloud group as a reader, which means its members are also snapshot readers. NOTE: This is an experimental feature and its response body may change.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.sync_duos_dataset_authorized_users(duos_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str duos_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DuosFirecloudGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.sync_duos_dataset_authorized_users_with_http_info(duos_id, **kwargs)  # noqa: E501

    def sync_duos_dataset_authorized_users_with_http_info(self, duos_id, **kwargs):  # noqa: E501
        """sync_duos_dataset_authorized_users  # noqa: E501

        Sync the DUOS dataset's authorized users as members of their corresponding TDR-managed Firecloud group.  Any snapshots linked to the DUOS dataset have this Firecloud group as a reader, which means its members are also snapshot readers. NOTE: This is an experimental feature and its response body may change.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.sync_duos_dataset_authorized_users_with_http_info(duos_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str duos_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DuosFirecloudGroupModel, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'duos_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method sync_duos_dataset_authorized_users" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'duos_id' is set
        if self.api_client.client_side_validation and ('duos_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['duos_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `duos_id` when calling `sync_duos_dataset_authorized_users`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'duos_id' in local_var_params:
            path_params['duosId'] = local_var_params['duos_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['googleoauth', 'oidc']  # noqa: E501

        return self.api_client.call_api(
            '/api/repository/v1/duos/{duosId}/syncAuthorizedUsers', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DuosFirecloudGroupModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
